patch_file_tool

Function patch_file_tool 

pub fn patch_file_tool() -> ToolDef
Create the patch_file tool.

Finds the exact occurrence of old_string in the file and replaces it with new_string. Errors if the string is not found or is ambiguous (multiple occurrences).